require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  
  # Module Operating System.
  module OS
    
    # Use Case Log service.
    module UseCaseLog
      
      # @see UseCaseLog#get_record_entry
      class UseCaseLogRecordEntry < UU::OS::REST::DTO
        
        # ID of a use case log record. Never nil.
        attr_accessor :id
        
        # Date and time, when the use case log record was created. Never nil.
        attr_accessor :creation_time
        
        # Enum value, which specifies a level of the use case log record. Never nil.
        #
        # @see UU::OS::UseCaseLog::UseCaseLogLevel
        attr_accessor :log_level
        
        # Message of a use case log record.
        attr_accessor :message
        
        # ID of the node, on which the use case was executed.
        attr_accessor :node_id
        
        # UESURI of the object, on which the use case was executed. The UESURI doesn't have to be a classic uri (canonical or normalized), but may only contain known parts of the uri e.g. code or oid. Never nil.
        attr_accessor :object_uri
        
        # Code of the territory, where the use case was executed.
        attr_accessor :territory_code
        
        # Code of the artifact, on which the use case was executed. Never nil.
        attr_accessor :artifact_code
        
        # Name of the artifact, on which the use case was executed. Never nil.
        attr_accessor :artifact_name
        
        # Code of the object, on which the use case was executed. Never nil.
        attr_accessor :object_code
        
        # Name of the object, on which the use case was executed. Never nil.
        attr_accessor :object_name
        
        # UESURI of the access role, who has executed the use case. The UESURI doesn't have to be a classic uri (canonical or normalized), but may only contain known parts of the uri e.g. code or oid. Never nil.
        attr_accessor :access_role_uri
        
        # Code of the access role, who has executed the use case. Never nil.
        attr_accessor :access_role_code
        
        # Name of the access role, who has executed the use case. Never nil.
        attr_accessor :access_role_name
        
        # UESURI of the executive role, ... . The UESURI doesn't have to be a classic uri (canonical or normalized), but may only contain known parts of the uri e.g. code or oid. Never nil.
        attr_accessor :executive_role_uri
        
        # Code of the executive role, ... . Never nil.
        attr_accessor :executive_role_code

        # Name of the executive role, ... .
        attr_accessor :executive_role_name
        
        # Code of the uuApp, in which the use case was executed.
        attr_accessor :client_app_code
        
        # Code of the uuApp... .
        attr_accessor :app_code
        
        # Code of the use case. Never nil.
        attr_accessor :use_case_code
        
        # Name of the use case. Never nil.
        attr_accessor :use_case_name
        
        # Enum value, which specifies a type of the use case. Never nil.
        #
        # @see UU::OS::UseCaseLog::UseCaseLogType
        attr_accessor :use_case_type
        
        # Duration time of the use case. Never nil.
        attr_accessor :use_case_duration
      
        def id
          return attributes[:id]
        end

        def id=(value)
          attributes[:id] = value
        end

        def creation_time
          return attributes[:creationTime]
        end

        def creation_time=(value)
          attributes[:creationTime] = value
        end

        def log_level
          return attributes[:logLevel]
        end

        def log_level=(value)
          attributes[:logLevel] = value
        end

        def message
          return attributes[:message]
        end

        def message=(value)
          attributes[:message] = value
        end

        def node_id
          return attributes[:nodeId]
        end

        def node_id=(value)
          attributes[:nodeId] = value
        end

        def object_uri
          return attributes[:objectUri]
        end
        
        def object_uri=(value)
          attributes[:objectUri] = (value != nil) ? UU::OS::UESURI.new(value) : nil
        end
        
        def territory_code
          return attributes[:territoryCode]
        end

        def territory_code=(value)
          attributes[:territoryCode] = value
        end
        
        def artifact_code
          return attributes[:artifactCode]
        end

        def artifact_code=(value)
          attributes[:artifactCode] = value
        end
        
        def artifact_name
          return attributes[:artifactName]
        end

        def artifact_name=(value)
          attributes[:artifactName] = value
        end
        
        def object_code
          return attributes[:objectCode]
        end

        def object_code=(value)
          attributes[:objectCode] = value
        end

        def object_name
          return attributes[:objectName]
        end

        def object_name=(value)
          attributes[:objectName] = value
        end
        
        def access_role_uri
          return attributes[:accessRoleUri]
        end
        
        def access_role_uri=(value)
          attributes[:accessRoleUri] = (value != nil) ? UU::OS::UESURI.new(value) : nil
        end
        
        def access_role_code
          return attributes[:accessRoleCode]
        end
        
        def access_role_code=(value)
          attributes[:accessRoleCode] = value
        end
        
        def access_role_name
          return attributes[:accessRoleName]
        end
        
        def access_role_name=(value)
          attributes[:accessRoleName] = value
        end
        
        def executive_role_uri
          return attributes[:executiveRoleUri]
        end

        def executive_role_uri=(value)
          attributes[:executiveRoleUri] = (value != nil) ? UU::OS::UESURI.new(value) : nil
        end
        
        def executive_role_code
          return attributes[:executiveRoleCode]
        end

        def executive_role_code=(value)
          attributes[:executiveRoleCode] = value
        end
        
        def executive_role_name
          return attributes[:executiveRoleName]
        end

        def executive_role_name=(value)
          attributes[:executiveRoleName] = value
        end
        
        def client_app_code
          return attributes[:clientAppCode]
        end

        def client_app_code=(value)
          attributes[:clientAppCode] = value
        end

        def app_code
          return attributes[:appCode]
        end

        def app_code=(value)
          attributes[:appCode] = value
        end
        
        def use_case_code
          return attributes[:useCaseCode]
        end

        def use_case_code=(value)
          attributes[:useCaseCode] = value
        end

        def use_case_name
          return attributes[:useCaseName]
        end

        def use_case_name=(value)
          attributes[:useCaseName] = value
        end

        def use_case_type
          return attributes[:useCaseType]
        end

        def use_case_type=(value)
          attributes[:useCaseType] = value
        end
        
        def use_case_duration
          return attributes[:useCaseDuration]
        end

        def use_case_duration=(value)
          attributes[:useCaseDuration] = value
        end
   
      end
    end
  end
end